package de.fhhannover.inform.trust.ifmapj;

import java.util.Collection;

import de.fhhannover.inform.trust.ifmapj.channel.SSRC;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapErrorResult;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapException;
import de.fhhannover.inform.trust.ifmapj.identifier.IdentifierFactory;
import de.fhhannover.inform.trust.ifmapj.identifier.IpAddress;
import de.fhhannover.inform.trust.ifmapj.messages.PublishRequest;
import de.fhhannover.inform.trust.ifmapj.messages.PublishUpdate;
import de.fhhannover.inform.trust.ifmapj.messages.RequestFactory;
import de.fhhannover.inform.trust.ifmapj.messages.ResultItem;
import de.fhhannover.inform.trust.ifmapj.messages.SearchRequest;
import de.fhhannover.inform.trust.ifmapj.messages.SearchResult;
import de.fhhannover.inform.trust.ifmapj.metadata.StandardIfmapMetadataFactory;

public class LoopLink {
	
	public static void main(String[] args) throws IfmapErrorResult, IfmapException {
	
		IfmapJHelper.setSystemProperties(
				ConfData.TRUST_STORE_PATH,
				ConfData.TRUST_STORE_PASSWORD,
				ConfData.KEY_STORE_PATH,
				ConfData.KEY_STORE_PASSWORD);
				
		SSRC ssrc = IfmapJ.createSSRC(
				ConfData.BASIC_AUTH_SERVER_URL,
				ConfData.BASIC_AUTH_USER,
				ConfData.BASIC_AUTH_PASSWORD,
				IfmapJHelper.getTrustManagers());
		
		RequestFactory rF = IfmapJ.createRequestFactory();
		IdentifierFactory iF = IfmapJ.createIdentifierFactory();
		StandardIfmapMetadataFactory mF = IfmapJ.createStandardMetadataFactory();
		
		PublishRequest pr = rF.createPublishReq();
		PublishUpdate pu = rF.createPublishUpdate();
		SearchRequest sr = rF.createSearchRequest();
		
		IpAddress ip = iF.createIp4("192.168.0.1");
		System.out.println(ip);
		pu.setIdentifier1(ip);
		pu.setIdentifier2(ip);
		pu.addMetadata(mF.createIpMac(null, null, null));
		pr.addPublishElement(pu);
		
		sr.setStartIdentifier(ip);
		sr.setMaxDepth(10);
		
		ssrc.newSession();
		ssrc.publish(pr);
		
		SearchResult sres = ssrc.search(sr);
		Collection<ResultItem> ris = sres.getResultItems();
		for (ResultItem ri : ris) {
			System.out.println("identifier1=" + ri.getIdentifier1());
			System.out.println("identifier2=" + ri.getIdentifier2());
		}
		
		ip.setAdministrativeDomain("helloWorld");
		System.out.println(ip);
		
		ssrc.publish(pr);
		
		ssrc.endSession();
	}

}
