package de.fhhannover.inform.trust.ifmapj;

import de.fhhannover.inform.trust.ifmapj.channel.ARC;
import de.fhhannover.inform.trust.ifmapj.channel.SSRC;
import de.fhhannover.inform.trust.ifmapj.exception.EndSessionException;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapErrorResult;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapException;
import de.fhhannover.inform.trust.ifmapj.exception.InitializationException;
import de.fhhannover.inform.trust.ifmapj.log.IfmapJLog;

public class NewSessionPlayground {
	
	public static void main(String[] args) throws InitializationException, InterruptedException {
		
		IfmapJHelper.setSystemProperties(
				ConfData.TRUST_STORE_PATH,
				ConfData.TRUST_STORE_PASSWORD,
				ConfData.KEY_STORE_PATH,
				ConfData.KEY_STORE_PASSWORD);
		
		try {
			SSRC ssrc = IfmapJ.createSSRC(
					ConfData.BASIC_AUTH_SERVER_URL,
					ConfData.BASIC_AUTH_USER,
					ConfData.BASIC_AUTH_PASSWORD,
					IfmapJHelper.getTrustManagers());
					
			System.out.println("Doing newSession");
			ssrc.newSession();
			System.out.println("newSession successful");
			System.out.println("session-id=" + ssrc.getSessionId());
			System.out.println("ifmap-publisher-id=" + ssrc.getPublisherId());
			System.out.println("max-poll-result-size=" + ssrc.getMaxPollResSize());
			final ARC arc = ssrc.getArc();
			Thread.sleep(200);
			new Thread(new Runnable() {
				
				@Override
				public void run() {
					try {
						System.out.println("Doing poll...");
						arc.poll();
					} catch (EndSessionException e) {
						System.out.println("+++POLL RETURNED AS OF endSession");
					} catch (Exception e) {
						System.out.println("---POLL EXCEPTION");
					}
				}
			}).start();
			
			Thread.sleep(200);
			System.out.println("Doing newSession, again");
			Thread.sleep(50);
			ssrc.newSession(new Integer("1234"));
			Thread.sleep(50);
			System.out.println("newSession successful");
			System.out.println("session-id=" + ssrc.getSessionId());
			System.out.println("ifmap-publisher-id=" + ssrc.getPublisherId());
			System.out.println("max-poll-result-size=" + ssrc.getMaxPollResSize());
			Thread.sleep(700);
			ssrc.endSession();
			System.out.println("Doing endSession");
		} catch (IfmapErrorResult e) {
			IfmapJLog.warn(e.toString());
		} catch (IfmapException e) {
			System.out.println(e.getDescription());
			System.out.println(e.getMessage());
		}
	}
}
