package de.fhhannover.inform.trust.ifmapj;

import de.fhhannover.inform.trust.ifmapj.binding.IfmapStrings;
import de.fhhannover.inform.trust.ifmapj.channel.ARC;
import de.fhhannover.inform.trust.ifmapj.channel.SSRC;
import de.fhhannover.inform.trust.ifmapj.exception.EndSessionException;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapErrorResult;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapException;
import de.fhhannover.inform.trust.ifmapj.identifier.IdentifierFactory;
import de.fhhannover.inform.trust.ifmapj.identifier.IpAddress;
import de.fhhannover.inform.trust.ifmapj.log.IfmapJLog;
import de.fhhannover.inform.trust.ifmapj.messages.PollResult;
import de.fhhannover.inform.trust.ifmapj.messages.PublishDelete;
import de.fhhannover.inform.trust.ifmapj.messages.PublishRequest;
import de.fhhannover.inform.trust.ifmapj.messages.PublishUpdate;
import de.fhhannover.inform.trust.ifmapj.messages.RequestFactory;
import de.fhhannover.inform.trust.ifmapj.messages.SearchResult;
import de.fhhannover.inform.trust.ifmapj.messages.SubscribeRequest;
import de.fhhannover.inform.trust.ifmapj.messages.SubscribeUpdate;
import de.fhhannover.inform.trust.ifmapj.metadata.StandardIfmapMetadataFactory;

/**
 * This is _not_ a real test, but more a Hello World Example!
 * 
 * @author aw
 *
 */
public class PollTest {
	
	private static IdentifierFactory ifac = IfmapJ.createIdentifierFactory();
	private static RequestFactory rf = IfmapJ.createRequestFactory();
	private static StandardIfmapMetadataFactory mf = IfmapJ.createStandardMetadataFactory();

	public static void main(String args[]) throws IfmapException, IfmapErrorResult, EndSessionException {
		
		PublishRequest pr1 = preparePublishRequestUpdate();
		PublishRequest pr2 = preparePublishRequestDelete();
		SubscribeRequest sr1 = prepareSubscribeRequest();

		IfmapJHelper.setSystemProperties(
				ConfData.TRUST_STORE_PATH,
				ConfData.TRUST_STORE_PASSWORD,
				ConfData.KEY_STORE_PATH,
				ConfData.KEY_STORE_PASSWORD);
		
		SSRC ssrc = IfmapJ.createSSRC(
				ConfData.CERT_AUTH_SERVER_URL,
				IfmapJHelper.getKeyManagers(),
				IfmapJHelper.getTrustManagers());
		
	/*	SSRC ssrc = IfmapJ.createSSRC(ConfData.BASIC_AUTH_SERVER_URL,
				ConfData.BASIC_AUTH_USER, ConfData.BASIC_AUTH_PASSWORD,
				IfmapJHelper.getTrustManagers()); */
		
		ssrc.setGzip(false);
		
		/* arc inherits gzip setting */
		ARC arc = ssrc.getArc();

		IfmapJLog.info("newSession");
		ssrc.newSession();
		ssrc.subscribe(sr1);
		PollResult pr = arc.poll();
		
		if (pr.getDeleteResults().size() != 0 && pr.getUpdateResults().size() != 0
				&& pr.getNotifyResults().size() != 0 && pr.getSearchResults().size() != 1) {
			IfmapJLog.error("Unexpected Results in PollResult");
		}
		
		if (!(pr.getSearchResults().iterator().next().getName().equals("test-subscription"))) {
			IfmapJLog.error("Wrong subscription name in result");
		}
			
		IfmapJLog.info("Add some metadata elements");
		ssrc.publish(pr1);
		
		IfmapJLog.info("poll for updateResult");
		pr = arc.poll();
		
		if (pr.getDeleteResults().size() != 0 && pr.getUpdateResults().size() != 1
				&& pr.getNotifyResults().size() != 0 && pr.getSearchResults().size() != 0) {
			IfmapJLog.error("Unexpected Results in PollResult 2");
		}

		SearchResult update = pr.getUpdateResults().iterator().next();

		if (!(update.getName().equals("test-subscription"))) {
			IfmapJLog.error("Wrong subscription name in result");
		}
		
		if (update.getResultItems().size() != 1) {
		if (!(update.getName().equals("test-subscription"))) {
			IfmapJLog.error("Wrong subscription name in result");
		}
		
			IfmapJLog.error("Unexpected number of result items");
		}
		
		if (update.getResultItems().iterator().next().getMetadata().size() != 4) {
			IfmapJLog.error("Unexpected number of metadata in result item");
		}
	
		IfmapJLog.info("Delete all the stuff again");
		ssrc.publish(pr2);

		IfmapJLog.info("poll for deleteResult");
		pr = arc.poll();
		if (pr.getDeleteResults().size() != 1 && pr.getUpdateResults().size() != 0
				&& pr.getNotifyResults().size() != 0 && pr.getSearchResults().size() != 0) {
			IfmapJLog.error("Unexpected Results in PollResult 3");
		}
		
		SearchResult delete = pr.getDeleteResults().iterator().next();
		if (delete.getResultItems().size() != 1) {
			IfmapJLog.error("Unexpected number of result items");
		}

		if (!(delete.getName().equals("test-subscription"))) {
			IfmapJLog.error("Wrong subscription name in result");
		}
		
		
		if (update.getResultItems().iterator().next().getMetadata().size() != 4) {
			IfmapJLog.error("Unexpected number of metadata in result item");
		}
	
		IfmapJLog.info("endSession");
		ssrc.endSession();
	}

	private static PublishRequest preparePublishRequestUpdate() {
		PublishRequest ret = rf.createPublishReq();
		PublishUpdate update = rf.createPublishUpdate();
		IpAddress ip = ifac.createIp4("192.168.0.1");
		update.setIdentifier1(ip);
		update.addMetadata(mf.createIpMac());
		update.addMetadata(mf.createIpMac());
		update.addMetadata(mf.createIpMac());
		update.addMetadata(mf.createIpMac());
		ret.addPublishElement(update);
		return ret;
	}

	private static SubscribeRequest prepareSubscribeRequest() {
		SubscribeRequest sr = rf.createSubscribeReq();
		SubscribeUpdate su = rf.createSubscribeUpdate();
		su.setName("test-subscription");
		sr.addSubscribeElement(su);
		IpAddress ip = ifac.createIp4("192.168.0.1");
		su.setStartIdentifier(ip);
		return sr;
	}
	
	private static PublishRequest preparePublishRequestDelete() {
		PublishRequest ret = rf.createPublishReq();
		PublishDelete delete = rf.createPublishDelete();
		IpAddress ip = ifac.createIp4("192.168.0.1");
		delete.setIdentifier1(ip);
		delete.setFilter("meta:ip-mac");
		delete.addNamespaceDeclaration(
				IfmapStrings.STD_METADATA_PREFIX,
				IfmapStrings.STD_METADATA_NS_URI);
		ret.addPublishElement(delete);
		return ret;
	}
}
