package de.fhhannover.inform.trust.ifmapj;

import de.fhhannover.inform.trust.ifmapj.binding.IfmapStrings;
import de.fhhannover.inform.trust.ifmapj.channel.SSRC;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapErrorResult;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapException;
import de.fhhannover.inform.trust.ifmapj.identifier.IdentifierFactory;
import de.fhhannover.inform.trust.ifmapj.identifier.IpAddress;
import de.fhhannover.inform.trust.ifmapj.messages.PublishDelete;
import de.fhhannover.inform.trust.ifmapj.messages.PublishNotify;
import de.fhhannover.inform.trust.ifmapj.messages.PublishRequest;
import de.fhhannover.inform.trust.ifmapj.messages.PublishUpdate;
import de.fhhannover.inform.trust.ifmapj.messages.RequestFactory;
import de.fhhannover.inform.trust.ifmapj.metadata.StandardIfmapMetadataFactory;

/**
 * This is _not_ a real test, but more a Hello World Example!
 * 
 * @author aw
 *
 */
public class PublishTest {
	private static RequestFactory rf = IfmapJ.createRequestFactory();
	private static IdentifierFactory ifac = IfmapJ.createIdentifierFactory();
	private static StandardIfmapMetadataFactory mf = IfmapJ.createStandardMetadataFactory();

	public static void main(String args[]) throws IfmapErrorResult, IfmapException {
		
		PublishRequest pr1 = preparePublishRequestUpdate();
		PublishRequest pr2 = preparePublishRequestDelete();
		PublishRequest pr3 = preparePublishRequestNotify();
		
		SSRC ssrc = IfmapJ.createSSRC(
				ConfData.BASIC_AUTH_SERVER_URL,
				ConfData.BASIC_AUTH_USER,
				ConfData.BASIC_AUTH_PASSWORD,
				IfmapJHelper.getTrustManagers(
						ConfData.TRUST_STORE_PATH,
						ConfData.TRUST_STORE_PASSWORD)
				);
		
		ssrc.newSession();
		ssrc.publish(pr1);
		ssrc.publish(pr2);
		ssrc.publish(pr3);
		ssrc.endSession();
	}

	private static PublishRequest preparePublishRequestNotify() {
		PublishRequest ret = rf.createPublishReq();
		PublishNotify notify = rf.createPublishNotify();
		IpAddress ip = ifac.createIp4("192.168.0.1");
		notify.setIdentifier1(ip);
		notify.addMetadata(mf.createIpMac());
		ret.addPublishElement(notify);
		return ret;
	}

	private static PublishRequest preparePublishRequestDelete() {
		PublishRequest ret = rf.createPublishReq();
		PublishDelete delete = rf.createPublishDelete();
		IpAddress ip = ifac.createIp4("192.168.0.1");
		delete.setIdentifier1(ip);
		delete.setFilter("meta:ip-mac");
		delete.addNamespaceDeclaration(
				IfmapStrings.STD_METADATA_PREFIX,
				IfmapStrings.STD_METADATA_NS_URI);
		ret.addPublishElement(delete);
		return ret;
	}

	private static PublishRequest preparePublishRequestUpdate() {
		PublishRequest ret = rf.createPublishReq();
		PublishUpdate update = rf.createPublishUpdate();
		IpAddress ip = ifac.createIp4("192.168.0.1");
		update.setIdentifier1(ip);
		update.addMetadata(mf.createIpMac());
		ret.addPublishElement(update);
		return ret;
	}
}
