package de.fhhannover.inform.trust.ifmapj.messages;

import de.fhhannover.inform.trust.ifmapj.binding.Unmarshaller;
import de.fhhannover.inform.trust.ifmapj.identifier.Identifier;

/**
 * Interface to access {@link Identifier} objects in elements that hold them.
 * 
 * An element containing up to two {@link Identifier} objects, as it is the
 * case for {@link PublishUpdate}, {@link PublishNotify}, {@link PublishDelete}
 * {@link ResultItem}.
 * 
 * An {@link Unmarshaller} implementation should create {@link ResultItem}
 * objects where {@link #getIdentifier1()} always returns a non-null value and
 * {@link #getIdentifier2()} return a non-null value if and only if the element
 * just unmarshalled contains two {@link Identifier}.
 * 
 * @author aw
 *
 */
public interface IdentifierHolder {
	
	/**
	 * @return the first identifier attached to this element.
	 */
	public Identifier getIdentifier1();
	
	/**
	 * @param id the {@link Identifier} to be set.
	 * @throws NullPointerException if the given {@link Identifier} is null.
	 */
	public void setIdentifier1(Identifier id);
	
	/**
	 * @return the second identifier attached to this element.
	 */
	public Identifier getIdentifier2();
	
	/**
	 * @param id the {@link Identifier} to be set.
	 * @throws NullPointerException if the given {@link Identifier} is null.
	 */
	public void setIdentifier2(Identifier id);
	
	/**
	 * @return an array of size 2, containing references to both identifiers,
	 *         or null entries if appropriate
	 */
	public Identifier[] getIdentifier();
	
	/**
	 * @return true if both identifiers are non-null.
	 */
	public boolean holdsLink();
}
