package de.fhhannover.inform.trust.ifmapj.messages;

import java.util.Collection;
import java.util.List;


public class RequestFactoryImpl implements RequestFactoryInternal, RequestFactory {

	@Override
	public PublishRequest createPublishReq() {
		return new PublishRequestImpl();
	}
	
	@Override
	public PublishRequest createPublishReq(PublishElement el) {
		if (el == null)
			throw new NullPointerException("el is not allowed to be null");
		
		PublishRequest ret = createPublishReq();
		ret.addPublishElement(el);
		return ret;
	}

	@Override
	public PublishRequest createPublishReq(Collection<PublishElement> list) {
		if (list == null)
			throw new NullPointerException("list is not allowed to be null");

		PublishRequest ret = createPublishReq();
		for (PublishElement el : list)
			ret.addPublishElement(el);
		
		return ret;
	}

	@Override
	public NewSessionRequest createNewSessionReq() {
		return new NewSessionRequestImpl();
	}

	@Override
	public EndSessionRequest createEndSessionReq() {
		return new EndSessionRequestImpl();
	}

	@Override
	public RenewSessionRequest createRenewSessionReq() {
		return new RenewSessionRequestImpl();
	}

	@Override
	public PurgePublisherRequest createPurgePublisherReq() {
		return new PurgePublisherRequestImpl();
	}

	@Override
	public PollRequest createPollReq() {
		return new PollRequestImpl();
	}

	@Override
	public PublishUpdate createPublishUpdate() {
		return new PublishUpdateImpl();
	}

	@Override
	public PublishNotify createPublishNotify() {
		return new PublishNotifyImpl();
	}

	@Override
	public PublishDelete createPublishDelete() {
		return new PublishDeleteImpl();
	}

	@Override
	public SubscribeRequest createSubscribeReq() {
		return new SubscribeRequestImpl();
	}
	
	@Override
	public SubscribeRequest createSubscribeReq(SubscribeElement el) {
		if (el == null)
			throw new NullPointerException("el is not allowed to be null");
		
		SubscribeRequest ret = createSubscribeReq();
		ret.addSubscribeElement(el);
		return ret;
	}

	@Override
	public SubscribeRequest createSubscribeReq(List<SubscribeElement> list) {
		if (list == null)
			throw new NullPointerException("list is not allowed to be null");
		
		SubscribeRequest ret = createSubscribeReq();
		for (SubscribeElement el : list)
			ret.addSubscribeElement(el);
		
		return ret;
	}

	@Override
	public SubscribeUpdate createSubscribeUpdate() {
		return new SubscribeUpdateImpl(new SearchHolderImpl());
	}

	@Override
	public SubscribeDelete createSubscribeDelete() {
		return new SubscribeDeleteImpl();
	}

	@Override
	public SearchRequest createSearchRequest() {
		return new SearchRequestImpl(new SearchHolderImpl());
	}
}
